import { IReactionDisposer } from "mobx";
import { ErrorMessage, ValidationContextBuilder, ValidationFunction, ValidationObj } from "./validation";
import { Nullable } from "./utils";
export interface FieldType<TValue> {
    markAsTouched: () => void;
    markAsUntouched: () => void;
    setValue: (val: TValue, opts?: SetValueOpts) => void;
    reset: (opts?: ResetOpts) => void;
    readonly value: TValue;
    readonly isValid: boolean;
    readonly interacted: boolean;
    readonly pristine: boolean;
    readonly errorMessage: ErrorMessage;
    readonly validation: ValidationObj;
}
export interface FieldOpts<TValue, TInputValue> {
    validate?: ValidationFunction<Nullable<TValue>> | ValidationFunction<Nullable<TValue>>[];
    debounce?: boolean;
    disabled?: boolean;
    parser?: (value: TInputValue) => Nullable<TValue>;
    formater?: (value: TValue) => Nullable<TInputValue>;
    validationContext?: ValidationContextBuilder<Nullable<TValue>>;
    label?: string;
}
export interface SetValueOpts {
    interract?: boolean;
    isInitValue?: boolean;
}
export interface ResetOpts {
    untouched?: boolean;
    defaultValue?: boolean;
}
export default class Field<TValue, TInputValue = TValue> implements FieldType<Nullable<TValue>> {
    _value: Nullable<TValue>;
    _interacted: boolean;
    _validation: ValidationObj;
    disabled: boolean;
    validationContext: ValidationContextBuilder<Nullable<TValue>>;
    label?: string;
    parser?: (value: TInputValue) => Nullable<TValue>;
    formater?: (value: Nullable<TValue>) => Nullable<TInputValue>;
    _isValidFn: ValidationFunction<Nullable<TValue>>[];
    defaultValue: Nullable<TValue>;
    initValue: Nullable<TValue>;
    _dispose?: IReactionDisposer;
    reset({ untouched, defaultValue }?: ResetOpts): void;
    setDisabled(value: boolean): void;
    markAsTouched: () => void;
    markAsUntouched: () => void;
    get value(): Nullable<TValue>;
    setValue: (val: Nullable<TValue>, { interract, isInitValue }?: SetValueOpts) => void;
    onInputChange: (evt: any, value: TInputValue) => void;
    get inputValue(): TValue | TInputValue | null;
    setValidation(validation: ValidationObj): void;
    get errorMessage(): ErrorMessage;
    get isValid(): boolean;
    get validation(): ValidationObj;
    get interacted(): boolean;
    get pristine(): boolean;
    validate: () => Promise<void>;
    onChange(fn: (value: Nullable<TValue>) => void): void;
    destroy(): void;
    constructor(defaultValue: Nullable<TValue>, { validate, debounce, disabled, validationContext, formater, parser, label, }: FieldOpts<Nullable<TValue>, TInputValue>);
}
