import Field, { FieldType, SetValueOpts, ResetOpts } from "./Field";
import FieldsArray, { FieldsArrayData } from "./FieldsArray";
import { ValidationObj } from "./validation";
export declare type FieldsObjectType<T> = {
    [P in keyof T]: T[P] extends Field<infer U, infer V> ? Field<U, V> : T[P] extends FieldsObject<infer U> ? FieldsObject<U> : T[P] extends FieldsArray<infer U> ? FieldsArray<U> : never;
};
export declare type FieldsObjectData<T> = {
    [P in keyof T]: T[P] extends Field<infer U, infer V> ? U : T[P] extends FieldsObject<infer U> ? FieldsObjectData<U> : T[P] extends FieldsArray<infer U> ? FieldsArrayData<U>[] : never;
};
export declare type FieldsObjectValidator<T> = (val: T) => ValidationObj;
export declare type FieldsObjectOpts<TFields> = {
    validate?: FieldsObjectValidator<FieldsObjectData<TFields>>;
    data?: Partial<FieldsObjectData<TFields>>;
};
export default class FieldsObject<TFields> implements FieldType<FieldsObjectData<TFields>> {
    fields: TFields;
    defaultValue: FieldsObjectData<TFields>;
    initValue: Partial<FieldsObjectData<TFields>>;
    validate?: FieldsObjectValidator<FieldsObjectData<TFields>>;
    constructor(fields: TFields, { validate, data }?: FieldsObjectOpts<TFields>);
    reset({ untouched, defaultValue }?: ResetOpts): void;
    markAsTouched(): void;
    markAsUntouched(): void;
    setValue(newData: Partial<FieldsObjectData<TFields>>, { interract, isInitValue }?: SetValueOpts): void;
    get validation(): ValidationObj;
    get isValid(): boolean;
    get value(): FieldsObjectData<TFields>;
    get interacted(): boolean;
    get pristine(): boolean;
    get errorMessage(): import("./validation").ErrorMessage;
}
