"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var mobx_1 = require("mobx");
var fastDeepEqual = require("fast-deep-equal");
var FieldsObject = /** @class */ (function () {
    function FieldsObject(fields, _a) {
        var _b = _a === void 0 ? {} : _a, validate = _b.validate, data = _b.data;
        this.validate = validate;
        this.fields = mobx_1.observable.object(fields, {}, { deep: false });
        if (data) {
            this.setValue(data, { interract: false });
        }
        this.defaultValue = this.value;
        this.initValue = this.value;
    }
    FieldsObject.prototype.reset = function (_a) {
        var _b = _a === void 0 ? {} : _a, _c = _b.untouched, untouched = _c === void 0 ? false : _c, _d = _b.defaultValue, defaultValue = _d === void 0 ? false : _d;
        if (defaultValue) {
            this.initValue = this.defaultValue;
        }
        this.setValue(this.initValue);
        if (untouched) {
            this.markAsUntouched();
        }
    };
    FieldsObject.prototype.markAsTouched = function () {
        Object.values(this.fields).forEach(function (field) {
            return field.markAsTouched();
        });
    };
    FieldsObject.prototype.markAsUntouched = function () {
        Object.values(this.fields).forEach(function (field) {
            return field.markAsUntouched();
        });
    };
    FieldsObject.prototype.setValue = function (newData, _a) {
        var _this = this;
        var _b = _a === void 0 ? {} : _a, _c = _b.interract, interract = _c === void 0 ? false : _c, _d = _b.isInitValue, isInitValue = _d === void 0 ? false : _d;
        if (!newData) {
            return;
        }
        Object.keys(this.fields).forEach(function (fieldName) {
            if (newData[fieldName] !== undefined) {
                _this.fields[fieldName].setValue(newData[fieldName], {
                    interract: interract,
                    isInitValue: isInitValue,
                });
            }
        });
        if (isInitValue) {
            this.initValue = newData;
        }
    };
    Object.defineProperty(FieldsObject.prototype, "validation", {
        get: function () {
            if (this.validate) {
                var validation = this.validate(this.value);
                if (!validation.valid) {
                    return validation;
                }
            }
            var invalidField = Object.values(this.fields).find(function (field) { return !field.isValid; });
            if (invalidField) {
                return invalidField.validation;
            }
            return {
                valid: true,
            };
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FieldsObject.prototype, "isValid", {
        get: function () {
            return this.validation.valid;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FieldsObject.prototype, "value", {
        get: function () {
            var _this = this;
            var res = {};
            Object.keys(this.fields).forEach(function (fieldName) {
                res[fieldName] = _this.fields[fieldName].value;
            });
            return res;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FieldsObject.prototype, "interacted", {
        get: function () {
            return Object.values(this.fields).some(function (field) { return field.interacted; });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FieldsObject.prototype, "pristine", {
        get: function () {
            return fastDeepEqual(this.initValue, this.value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FieldsObject.prototype, "errorMessage", {
        get: function () {
            return this.validation.message || "";
        },
        enumerable: true,
        configurable: true
    });
    __decorate([
        mobx_1.observable,
        __metadata("design:type", Object)
    ], FieldsObject.prototype, "fields", void 0);
    __decorate([
        mobx_1.observable,
        __metadata("design:type", Object)
    ], FieldsObject.prototype, "initValue", void 0);
    __decorate([
        mobx_1.action("FIELD_OBJECT_RESET"),
        __metadata("design:type", Function),
        __metadata("design:paramtypes", [Object]),
        __metadata("design:returntype", void 0)
    ], FieldsObject.prototype, "reset", null);
    __decorate([
        mobx_1.action("FIELD_OBJECT_MAT"),
        __metadata("design:type", Function),
        __metadata("design:paramtypes", []),
        __metadata("design:returntype", void 0)
    ], FieldsObject.prototype, "markAsTouched", null);
    __decorate([
        mobx_1.action("FIELD_OBJECT_MAUT"),
        __metadata("design:type", Function),
        __metadata("design:paramtypes", []),
        __metadata("design:returntype", void 0)
    ], FieldsObject.prototype, "markAsUntouched", null);
    __decorate([
        mobx_1.action("FIELD_OBJECT_SETVALUE"),
        __metadata("design:type", Function),
        __metadata("design:paramtypes", [Object, Object]),
        __metadata("design:returntype", void 0)
    ], FieldsObject.prototype, "setValue", null);
    __decorate([
        mobx_1.computed,
        __metadata("design:type", Object),
        __metadata("design:paramtypes", [])
    ], FieldsObject.prototype, "validation", null);
    __decorate([
        mobx_1.computed,
        __metadata("design:type", Object),
        __metadata("design:paramtypes", [])
    ], FieldsObject.prototype, "isValid", null);
    __decorate([
        mobx_1.computed,
        __metadata("design:type", Object),
        __metadata("design:paramtypes", [])
    ], FieldsObject.prototype, "value", null);
    __decorate([
        mobx_1.computed,
        __metadata("design:type", Object),
        __metadata("design:paramtypes", [])
    ], FieldsObject.prototype, "interacted", null);
    __decorate([
        mobx_1.computed,
        __metadata("design:type", Object),
        __metadata("design:paramtypes", [])
    ], FieldsObject.prototype, "pristine", null);
    __decorate([
        mobx_1.computed,
        __metadata("design:type", Object),
        __metadata("design:paramtypes", [])
    ], FieldsObject.prototype, "errorMessage", null);
    return FieldsObject;
}());
exports.default = FieldsObject;
//# sourceMappingURL=FieldObject.js.map