"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var isEmail_1 = require("validator/lib/isEmail");
var isMobilePhone_1 = require("validator/lib/isMobilePhone");
var isPostalCode_1 = require("validator/lib/isPostalCode");
var validation_1 = require("../validation");
exports.isEmail = function (code) { return function (context) {
    var isValid = !context.value || isEmail_1.default(context.value);
    return isValid
        ? validation_1.next()
        : validation_1.error(code || "validation.wrong-email", { label: context.label });
}; };
exports.isRequired = function (code) { return function (context) {
    var value = context.value;
    var isValid = !!value;
    if (isValid && value.push) {
        // If is array then length must be > 0
        isValid = !!value.length;
    }
    return isValid
        ? validation_1.next()
        : validation_1.error(code || "validation.required", { label: context.label });
}; };
exports.maxLength = function (maxLength, code) { return function (context) {
    if (!context.value) {
        return validation_1.stop();
    }
    var isValid = !context.value || context.value.length <= maxLength;
    return isValid
        ? validation_1.next()
        : validation_1.error(code || "validation.max-length", {
            label: context.label,
            maxLength: maxLength,
        });
}; };
// export const isInt = (message: string, { max, min }: { max?: number; min?: number }) => (
//   context: ValidationContext<string | number>
// ): ValidationObj => {
//   if (!context.value) {
//     return stop();
//   }
//   let isValid = Number.isInteger(context.value);
//   if (isValid && max) {
//     isValid = context.value <= max;
//   }
//   if (isValid && min) {
//     isValid = context.value >= min;
//   }
//   return isValid ? next() : error(message);
// };
exports.isPositiveNumber = function (code) { return function (context) {
    if (!context.value) {
        return validation_1.stop();
    }
    var isValid = context.value > 0;
    return isValid
        ? validation_1.next()
        : validation_1.error(code || "validation.not-positive-number", {
            label: context.label,
            maxLength: exports.maxLength,
        });
}; };
exports.isPostalCode = function (code) { return function (context) {
    if (!context.value) {
        return validation_1.stop();
    }
    var isValid = isPostalCode_1.default(context.value, "FR");
    return isValid
        ? validation_1.next()
        : validation_1.error(code || "validation.not-postal-code", {
            label: context.label,
            maxLength: exports.maxLength,
        });
}; };
exports.isPhoneNumber = function (code) { return function (context) {
    if (!context.value) {
        return validation_1.stop();
    }
    var isValid = isMobilePhone_1.default(context.value, "fr-FR");
    return isValid
        ? validation_1.next()
        : validation_1.error(code || "validation.not-phone-number", {
            label: context.label,
            maxLength: exports.maxLength,
        });
}; };
// export function isDate(newValue, label) {
//   const isValid = !newValue || isValidDate(newValue);
//   return {
//     valid: isValid,
//     message: !isValid ? `${label} non valide` : ""
//   };
// }
// export function isAlphanumeric(newValue, label) {
//   const isValid = !newValue || !!newValue.match(/^[0-9A-Z-]+$/i);
//   return {
//     valid: isValid,
//     message: !isValid ? `${label || "Le champ"} doit être alphanumerique` : "",
//   };
// }
// export const forbiddenChar = (char, label, message) => newValue => {
//   let value = newValue;
//   let isValid = !value || !value.includes(char);
//   return {
//     valid: isValid,
//     message: !isValid
//       ? message || `${label || "Le champ"} ne doit pas contenir le caractère ${char}`
//       : "",
//   };
// };
// export const forbiddenChars = (chars = [], label, message) => value => {
//   let isValid =
//     !value ||
//     !chars.filter(char => {
//       return value.includes(char);
//     }).length > 0;
//   return {
//     valid: isValid,
//     message: !isValid
//       ? message || `${label || "Le champ"} ne doit pas contenir les caractères ${chars.join(" ")}`
//       : "",
//   };
// };
//# sourceMappingURL=index.js.map